1.0 (XX/07/2014)
================

- New repository: https://github.com/mayan-edms/mayan-edms
- Update required version of Django to 1.6
- Translation update and inclusion of new languages
- Use of related_name in some models
- Removal of circular imports
- Removal of included 3rd party modules
- Automatic testing and code coverage check
- Update of required modules and libraries versions
- Database connection leaks fixes
- Deletion of detached signatures
- Removal of fabric based installations
- New project structure
- New API system, browseable API, browseable API documentation
